@@ -1,21 +1,14 @@
 """Large and simple widget to indicate settings/Settings.
 """
-from ast import literal_eval
 from logging import getLogger
 
 from PyQt5.QtCore import QSettings, Qt
-from PyQt5.QtWidgets import (QCheckBox,
-                             QComboBox,
-                             QDialogButtonBox,
+from PyQt5.QtWidgets import (QDialogButtonBox,
                              QDialog,
-                             QFileDialog,
                              QFormLayout,
                              QGroupBox,
                              QHBoxLayout,
-                             QLineEdit,
                              QListWidget,
-                             QPushButton,
-                             QRadioButton,
                              QSplitter,
                              QStackedWidget,
                              QTextEdit,
@@ -23,6 +16,8 @@ from PyQt5.QtWidgets import (QCheckBox,
                              QWidget,
                              )
 
+from .utils import FormInt, FormList, FormStr
+
 lg = getLogger(__name__)
 
 settings = QSettings("wonambi", "scroll_data")
@@ -694,467 +689,3 @@ class EvtAnalysisHelp(HelpDialog):
              )
         self.resize(500, 700)
         self.set_text(s)
-
-
-class FormBool(QCheckBox):
-    """Subclass QCheckBox to have a more consistent API across widgets.
-
-    Parameters
-    ----------
-    checkbox_label : str
-        label next to checkbox
-
-    """
-    def __init__(self, checkbox_label):
-        super().__init__(checkbox_label)
-
-    def get_value(self, default=False):
-        """Get the value of the QCheckBox, as boolean.
-
-        Parameters
-        ----------
-        default : bool
-            not used
-
-        Returns
-        -------
-        bool
-            state of the checkbox
-
-        """
-        return self.checkState() == Qt.Checked
-
-    def set_value(self, value):
-        """Set value of the checkbox.
-
-        Parameters
-        ----------
-        value : bool
-            value for the checkbox
-
-        """
-        if value:
-            self.setCheckState(Qt.Checked)
-        else:
-            self.setCheckState(Qt.Unchecked)
-
-    def connect(self, funct):
-        """Call funct when user ticks the box.
-
-        Parameters
-        ----------
-        funct : function
-            function that broadcasts a change.
-
-        """
-        self.stateChanged.connect(funct)
-
-
-class FormRadio(QRadioButton):
-    """Subclass QRadioButton to have a more consistent API across widgets.
-
-    Parameters
-    ----------
-    checkbox_label : str
-        label next to checkbox
-
-    """
-    def __init__(self, checkbox_label):
-        super().__init__(checkbox_label)
-
-    def get_value(self, default=False):
-        """Get the value of the QCheckBox, as boolean.
-
-        Parameters
-        ----------
-        default : bool
-            not used
-
-        Returns
-        -------
-        bool
-            state of the checkbox
-
-        """
-        return self.isChecked  == Qt.Checked
-
-    def set_value(self, value):
-        """Set value of the checkbox.
-
-        Parameters
-        ----------
-        value : bool
-            value for the checkbox
-
-        """
-        if value:
-            self.setCheckState(Qt.Checked)
-        else:
-            self.setCheckState(Qt.Unchecked)
-
-    def connect(self, funct):
-        """Call funct when user ticks the box.
-
-        Parameters
-        ----------
-        funct : function
-            function that broadcasts a change.
-
-        """
-        self.toggled.connect(funct)
-
-
-class FormFloat(QLineEdit):
-    """Subclass QLineEdit for float to have a more consistent API across
-    widgets.
-
-    """
-    def __init__(self, default=None):
-        super().__init__('')
-        
-        if default is not None:
-            self.set_value(default)
-
-    def get_value(self, default=0):
-        """Get float from widget.
-
-        Parameters
-        ----------
-        default : float
-            default value for the parameter in case it fails
-
-        Returns
-        -------
-        float
-            the value in text or default
-
-        """
-        text = self.text()
-        try:
-            text = float(text)
-        except ValueError:
-            lg.debug('Cannot convert "' + str(text) + '" to float.' +
-                     'Using default ' + str(default))
-            text = default
-            self.set_value(text)
-        return text
-
-    def set_value(self, value):
-        """Set value of the float.
-
-        Parameters
-        ----------
-        value : float
-            value for the line edit
-
-        """
-        self.setText(str(value))
-
-    def connect(self, funct):
-        """Call funct when the text was changed.
-
-        Parameters
-        ----------
-        funct : function
-            function that broadcasts a change.
-
-        """
-        self.textEdited.connect(funct)
-
-
-class FormInt(QLineEdit):
-    """Subclass QLineEdit for int to have a more consistent API across widgets.
-
-    """
-    def __init__(self, default=None):
-        super().__init__('')
-        
-        if default is not None:
-            self.set_value(default)
-
-    def get_value(self, default=0):
-        """Get int from widget.
-
-        Parameters
-        ----------
-        default : int
-            default value for the parameter in case it fails
-
-        Returns
-        -------
-        int
-            the value in text or default
-
-        """
-        text = self.text()
-        try:
-            text = int(float(text))  # to convert values like 30.0
-        except ValueError:
-            lg.debug('Cannot convert "' + str(text) + '" to int. ' +
-                     'Using default ' + str(default))
-            text = default
-            self.set_value(text)
-        return text
-
-    def set_value(self, value):
-        """Set value of the int.
-
-        Parameters
-        ----------
-        value : int
-            value for the line edit
-
-        """
-        self.setText(str(value))
-
-    def connect(self, funct):
-        """Call funct when the text was changed.
-
-        Parameters
-        ----------
-        funct : function
-            function that broadcasts a change.
-
-        """
-        self.textEdited.connect(funct)
-
-
-class FormList(QLineEdit):
-    """Subclass QLineEdit for lists to have a more consistent API across
-    widgets.
-
-    """
-    def __init__(self):
-        super().__init__('')
-
-    def get_value(self, default=None):
-        """Get int from widget.
-
-        Parameters
-        ----------
-        default : list
-            list with widgets
-
-        Returns
-        -------
-        list
-            list that might contain int or str or float etc
-
-        """
-        if default is None:
-            default = []
-
-        try:
-            text = literal_eval(self.text())
-            if not isinstance(text, list):
-                pass
-                # raise ValueError
-
-        except ValueError:
-            lg.debug('Cannot convert "' + str(text) + '" to list. ' +
-                     'Using default ' + str(default))
-            text = default
-            self.set_value(text)
-
-        return text
-
-    def set_value(self, value):
-        """Set value of the list.
-
-        Parameters
-        ----------
-        value : list
-            value for the line edit
-
-        """
-        self.setText(str(value))
-
-    def connect(self, funct):
-        """Call funct when the text was changed.
-
-        Parameters
-        ----------
-        funct : function
-            function that broadcasts a change.
-
-        """
-        self.textEdited.connect(funct)
-
-
-class FormStr(QLineEdit):
-    """Subclass QLineEdit for str to have a more consistent API across widgets.
-
-    """
-    def __init__(self):
-        super().__init__('')
-
-    def get_value(self, default=''):
-        """Get int from widget.
-
-        Parameters
-        ----------
-        default : str
-            not used
-
-        Returns
-        -------
-        str
-            the value in text
-
-        """
-        return self.text()
-
-    def set_value(self, value):
-        """Set value of the string.
-
-        Parameters
-        ----------
-        value : str
-            value for the line edit
-
-        """
-        self.setText(value)
-
-    def connect(self, funct):
-        """Call funct when the text was changed.
-
-        Parameters
-        ----------
-        funct : function
-            function that broadcasts a change.
-
-        """
-        self.textEdited.connect(funct)
-
-
-class FormDir(QPushButton):
-    """Subclass QPushButton for str to have a more consistent API across widgets.
-
-    Notes
-    -----
-    It calls to open the directory three times, but I don't understand why
-
-    """
-    def __init__(self):
-        super().__init__('')
-
-    def get_value(self, default=''):
-        """Get int from widget.
-
-        Parameters
-        ----------
-        default : str
-            not used
-
-        Returns
-        -------
-        str
-            the value in text
-
-        """
-        return self.text()
-
-    def set_value(self, value):
-        """Set value of the string.
-
-        Parameters
-        ----------
-        value : str
-            value for the line edit
-
-        """
-        self.setText(value)
-
-    def connect(self, funct):
-        """Call funct when the text was changed.
-
-        Parameters
-        ----------
-        funct : function
-            function that broadcasts a change.
-
-        Notes
-        -----
-        There is something wrong here. When you run this function, it calls
-        for opening a directory three or four times. This is obviously wrong
-        but I don't understand why this happens three times. Traceback did not
-        help.
-
-        """
-        def get_directory():
-            rec = QFileDialog.getExistingDirectory(self,
-                                                   'Path to Recording'
-                                                   ' Directory')
-            if rec == '':
-                return
-
-            self.setText(rec)
-            funct()
-
-        self.clicked.connect(get_directory)
-
-class FormMenu(QComboBox):
-    """Subclass QComboBox for dropdown menus to have a more consistent API 
-    across widgets.
-    
-    Parameters
-    ----------
-    input_list: list of str
-        items to include in the dropdown menu / combobox
-    """
-    def __init__(self, input_list):
-        super().__init__()
-        
-        if input_list is not None:
-            for i in input_list:
-                self.addItem(i)
-
-    def get_value(self, default=None):
-        """Get selection from widget.
-
-        Parameters
-        ----------
-        default : str
-            str for use by widget
-
-        Returns
-        -------
-        str
-            selected item from the combobox
-
-        """
-        if default is None:
-            default = ''
-
-        try:
-            text = self.currentText()
-
-        except ValueError:
-            lg.debug('Cannot convert "' + str(text) + '" to list. ' +
-                     'Using default ' + str(default))
-            text = default
-            self.set_value(text)
-
-        return text
-
-    def set_value(self, value):
-        """Set value of the list.
-
-        Parameters
-        ----------
-        value : str
-            value for the combobox
-
-        """
-        self.setCurrentText(str(value))
-
-    def connect(self, funct):
-        """Call funct when the selection was changed.
-
-        Parameters
-        ----------
-        funct : function
-            function that broadcasts a change.
-
-        """
-        self.currentIndexChanged.connect(funct)
\ No newline at end of file
